@@ -17,11 +17,12 @@
 
 import argparse
 import logging
+import platform
 import sys
 
 logger = logging.getLogger(__name__)
 
-__version__ = "0.1.70"
+__version__ = "0.1.108"
 
 
 def setup_logger(config: argparse.Namespace) -> None:
@@ -57,3 +58,14 @@ def log_or_raise_on_warning(msg: str, raise_on_warning: bool = False) -> None:
         raise RuntimeError(msg)
 
     logger.warning(msg)
+
+
+def print_env() -> None:
+    """Print environment details for bug reporting."""
+    sys_version = sys.version.replace("\n", "")
+    print(
+        f"txt2ebook: {__version__}",
+        f"python: {sys_version}",
+        f"platform: {platform.platform()}",
+        sep="\n",
+    )
