@@ -96,6 +96,9 @@ class EpubWriter(BaseWriter):
         epub.write_epub(output_filename, book, {})
         logger.info("Generate EPUB file: %s", output_filename.resolve())
 
+        if self.config.open:
+            self._open_file(output_filename)
+
     def _build_nav(self, book: epub.EpubBook) -> None:
         book.add_item(epub.EpubNcx())
 
