@@ -151,6 +151,9 @@ class TxtWriter(BaseWriter):
             file.write(self._to_txt())
             logger.info("Generate TXT file: %s", new_filename.resolve())
 
+        if self.config.open:
+            self._open_file(new_filename)
+
     def _overwrite_file(self) -> None:
         txt_filename = Path(self.config.input_file.name)
 
@@ -158,6 +161,9 @@ class TxtWriter(BaseWriter):
             file.write(self._to_txt())
             logger.info("Overwrite txt file: %s", txt_filename.resolve())
 
+        if self.config.open:
+            self._open_file(txt_filename)
+
     def _to_txt(self) -> str:
         toc = self._to_toc("-") if self.config.with_toc else ""
         return self._to_metadata_txt() + toc + self._to_body_txt()
