@@ -18,6 +18,7 @@
 from txt2ebook.languages.zh_cn import (
     DEFAULT_RE_AUTHOR,
     DEFAULT_RE_CHAPTER,
+    DEFAULT_RE_INDEX,
     DEFAULT_RE_TAG,
     DEFAULT_RE_TITLE,
     DEFAULT_RE_TRANSLATOR,
@@ -39,6 +40,7 @@ __all__ = [
     "DEFAULT_RE_AUTHOR",
     "DEFAULT_RE_CHAPTER",
     "DEFAULT_RE_TAG",
+    "DEFAULT_RE_INDEX",
     "DEFAULT_RE_TITLE",
     "DEFAULT_RE_TRANSLATOR",
     "DEFAULT_RE_VOLUME",
