@@ -36,10 +36,10 @@ class Book:
     authors: List[str] = field(default_factory=lambda: [])
     translators: List[str] = field(default_factory=lambda: [])
     tags: List[str] = field(default_factory=lambda: [])
+    index: List[str] = field(default_factory=lambda: [])
     language: str = field(default="")
     cover: str = field(default="", repr=False)
     raw_content: str = field(default="", repr=False)
-    massaged_content: str = field(default="", repr=False)
     toc: List[Union[Volume, Chapter]] = field(
         default_factory=lambda: [], repr=False
     )
