@@ -52,19 +52,21 @@ class Parser:
         Returns:
           txt2ebook.models.Book: The Book model.
         """
-        massaged_content = self.massage()
-        tokenizer = Tokenizer(massaged_content, self.config)
+        tokenizer = Tokenizer(self.raw_content, self.config)
 
-        (book_title, authors, tags, toc) = self.parse_tokens(tokenizer)
+        (book_title, authors, translators, tags, index, toc) = (
+            self.parse_tokens(tokenizer)
+        )
 
         book = Book(
             title=book_title,
             language=self.config.language,
             authors=authors,
+            translators=translators,
             tags=tags,
+            index=index,
             cover=self.config.cover,
             raw_content=self.raw_content,
-            massaged_content=massaged_content,
             toc=toc,
         )
 
@@ -126,6 +128,7 @@ class Parser:
         book_title = ""
         authors = []
         tags = []
+        index = []
         translators = []
         current_volume = Volume("")
         current_chapter = Chapter("")
@@ -163,6 +166,9 @@ class Parser:
             if token.type == "TAG":
                 tags.append(token.value)
 
+            if token.type == "INDEX":
+                index = token.value.split(" ")
+
             if token.type == "TRANSLATOR":
                 translators.append(token.value)
 
@@ -216,15 +222,19 @@ class Parser:
         if self.config.title:
             book_title = self.config.title
 
+        if self.config.translator:
+            authors = self.config.translator
+
         logger.info("Found or set book title: %s", book_title)
         logger.info("Found or set authors: %s", repr(authors))
-        logger.info("Found or set categories: %s", repr(tags))
         logger.info("Found or set translators: %s", repr(translators))
+        logger.info("Found or set tags: %s", repr(tags))
+        logger.info("Found or set index: %s", repr(index))
 
         if self.config.sort_volume_and_chapter:
             self.sort_volume_and_chapter(toc)
 
-        return (book_title, authors, tags, toc)
+        return (book_title, authors, translators, tags, index, toc)
 
     def sort_volume_and_chapter(self, toc: List) -> None:
         """Sort by title of volumes and its chapters.
@@ -240,121 +250,3 @@ class Parser:
                 section.chapters.sort(key=lambda x: x.title)
 
         toc.sort(key=lambda x: x.title if isinstance(x, Volume) else "")
-
-    def massage(self) -> str:
-        """Massage the txt content.
-
-        Returns:
-            str: The formatted book content
-        """
-        content = self.raw_content
-
-        content = Parser.to_unix_newline(content)
-
-        if self.config.fullwidth and self.config.language in (
-            "zh-cn",
-            "zh-tw",
-        ):
-            logger.info("Convert halfwidth ASCII characters to fullwidth")
-            content = zh_halfwidth_to_fullwidth(content)
-
-        if self.config.re_delete:
-            content = self.do_delete_regex(content)
-
-        if self.config.re_replace:
-            content = self.do_replace_regex(content)
-
-        if self.config.re_delete_line:
-            content = self.do_delete_line_regex(content)
-
-        if self.config.width:
-            content = self.do_wrapping(content)
-
-        return content
-
-    @staticmethod
-    def to_unix_newline(content: str) -> str:
-        """Convert all other line ends to Unix line end.
-
-        Args:
-            content(str): The formatted book content.
-
-        Returns:
-            str: The formatted book content.
-        """
-        return content.replace("\r\n", "\n").replace("\r", "\n")
-
-    def do_delete_regex(self, content: str) -> str:
-        """Remove words/phrases based on regex.
-
-        Args:
-            content(str): The formatted book content.
-
-        Returns:
-            str: The formatted book content.
-        """
-        for delete_regex in self.config.re_delete:
-            content = re.sub(
-                re.compile(rf"{delete_regex}", re.MULTILINE), "", content
-            )
-        return content
-
-    def do_replace_regex(self, content: str) -> str:
-        """Replace words/phrases based on regex.
-
-        Args:
-            content(str): The formatted book content.
-
-        Returns:
-            str: The formatted book content.
-        """
-        regex = self.config.re_replace
-        if isinstance(regex, list):
-            for search, replace in regex:
-                content = re.sub(
-                    re.compile(rf"{search}", re.MULTILINE),
-                    rf"{replace}",
-                    content,
-                )
-
-        return content
-
-    def do_delete_line_regex(self, content: str) -> str:
-        """Delete whole line based on regex.
-
-        Args:
-            content(str): The formatted book content.
-
-        Returns:
-            str: The formatted book content.
-        """
-        for delete_line_regex in self.config.re_delete_line:
-            content = re.sub(
-                re.compile(rf"^.*{delete_line_regex}.*$", re.MULTILINE),
-                "",
-                content,
-            )
-        return content
-
-    def do_wrapping(self, content: str) -> str:
-        """Wrap or fill CJK text.
-
-        Args:
-            content (str): The formatted book content.
-
-        Returns:
-            str: The formatted book content.
-        """
-        logger.info("Wrapping paragraph to width: %s", self.config.width)
-
-        paragraphs = []
-        # We don't remove empty line and keep all formatting as it.
-        for paragraph in content.split("\n"):
-            paragraph = paragraph.strip()
-
-            lines = cjkwrap.wrap(paragraph, width=self.config.width)
-            paragraph = "\n".join(lines)
-            paragraphs.append(paragraph)
-
-        wrapped_content = "\n".join(paragraphs)
-        return wrapped_content
