@@ -22,14 +22,16 @@
 """
 
 import argparse
+import datetime
 import logging
 import sys
+import time
 from typing import Optional, Sequence
 
 from bs4 import UnicodeDammit
 from langdetect import detect
 
-from txt2ebook import __version__, setup_logger
+from txt2ebook import __version__, print_env, setup_logger
 from txt2ebook.exceptions import EmptyFileError
 from txt2ebook.formats import (
     EBOOK_FORMATS,
@@ -46,42 +48,47 @@ def run(config: argparse.Namespace) -> None:
     """Set the main application logic."""
     logger.debug(config)
 
-    logger.info("Parsing txt file: %s", config.input_file.name)
+    if config.env:
+        print_env()
+    else:
+        logger.info("Parsing txt file: %s", config.input_file.name)
 
-    unicode = UnicodeDammit(config.input_file.read())
-    logger.info("Detect encoding : %s", unicode.original_encoding)
+        unicode = UnicodeDammit(config.input_file.read())
+        logger.info("Detect encoding : %s", unicode.original_encoding)
 
-    content = unicode.unicode_markup
-    if not content:
-        raise EmptyFileError(f"Empty file content in {config.input_file.name}")
+        content = unicode.unicode_markup
+        if not content:
+            raise EmptyFileError(
+                f"Empty file content in {config.input_file.name}"
+            )
 
-    config_language = config.language
-    detect_language = detect(content)
-    config.language = config_language or detect_language
-    logger.info("Config language: %s", config_language)
-    logger.info("Detect language: %s", detect_language)
+        config_language = config.language
+        detect_language = detect(content)
+        config.language = config_language or detect_language
+        logger.info("Config language: %s", config_language)
+        logger.info("Detect language: %s", detect_language)
 
-    if config_language and config_language != detect_language:
-        logger.warning(
-            "Config (%s) and detect (%s) language mismatch",
-            config_language,
-            detect_language,
-        )
+        if config_language and config_language != detect_language:
+            logger.warning(
+                "Config (%s) and detect (%s) language mismatch",
+                config_language,
+                detect_language,
+            )
 
-    parser = Parser(content, config)
-    book = parser.parse()
+        parser = Parser(content, config)
+        book = parser.parse()
 
-    if config.test_parsing or config.debug:
-        book.debug(config.verbose)
+        if config.test_parsing or config.debug:
+            book.debug(config.verbose)
 
-    config.format = config.format or ["epub"]
-    if not config.test_parsing:
-        if book.toc:
-            for ebook_format in config.format:
-                writer = create_format(book, ebook_format, config)
-                writer.write()
-        else:
-            logger.warning("No table of content found, not exporting")
+        config.format = config.format or ["epub"]
+        if not config.test_parsing:
+            if book.toc:
+                for ebook_format in config.format:
+                    writer = create_format(book, ebook_format, config)
+                    writer.write()
+            else:
+                logger.warning("No table of content found, not exporting")
 
 
 def build_parser(
@@ -91,6 +98,7 @@ def build_parser(
     args = args or []
 
     parser = argparse.ArgumentParser(
+        prog="txt2ebook",
         add_help=False,
         description=__doc__,
         formatter_class=lambda prog: argparse.RawTextHelpFormatter(
@@ -101,24 +109,26 @@ def build_parser(
     epub = parser.add_argument_group("--format epub")
     pdf = parser.add_argument_group("--format pdf")
     txt = parser.add_argument_group("--format txt")
+    tex = parser.add_argument_group("--format tex")
     zhlang = parser.add_argument_group("--language zh-cn / --language zh-tw")
 
-    parser.add_argument(
-        "input_file",
-        nargs=None if sys.stdin.isatty() else "?",  # type: ignore
-        type=argparse.FileType("rb"),
-        default=None if sys.stdin.isatty() else sys.stdin,
-        help="source text filename",
-        metavar="TXT_FILENAME",
-    )
+    if "--env" not in args:
+        parser.add_argument(
+            "input_file",
+            nargs=None if sys.stdin.isatty() else "?",  # type: ignore
+            type=argparse.FileType("rb"),
+            default=None if sys.stdin.isatty() else sys.stdin,
+            help="source text filename",
+            metavar="TXT_FILENAME",
+        )
 
-    parser.add_argument(
-        "output_file",
-        nargs="?",
-        default=None,
-        help="converted ebook filename (default: 'TXT_FILENAME.epub')",
-        metavar="EBOOK_FILENAME",
-    )
+        parser.add_argument(
+            "output_file",
+            nargs="?",
+            default=None,
+            help="converted ebook filename (default: 'TXT_FILENAME.epub')",
+            metavar="EBOOK_FILENAME",
+        )
 
     parser.add_argument(
         "-of",
@@ -149,6 +159,15 @@ def build_parser(
         help="ebook format (default: 'epub')",
     )
 
+    parser.add_argument(
+        "-ik",
+        "--index-keyword",
+        dest="index_keyword",
+        action="append",
+        default=[],
+        help="keyword to index (default: '%(default)s')",
+    )
+
     parser.add_argument(
         "-t",
         "--title",
@@ -235,7 +254,7 @@ def build_parser(
         "-pz",
         "--page-size",
         dest="page_size",
-        default=None,
+        default="a5",
         choices=PAGE_SIZES,
         help="page size of the ebook (default: '%(default)s')",
         metavar="PAGE_SIZE",
@@ -325,6 +344,15 @@ def build_parser(
         metavar="REGEX",
     )
 
+    tex.add_argument(
+        "-ct",
+        "--clean-tex",
+        default=False,
+        action="store_true",
+        dest="clean_tex",
+        help="purge artifacts generated by TeX (default: '%(default)s')",
+    )
+
     epub.add_argument(
         "-et",
         "--epub-template",
@@ -418,6 +446,15 @@ def build_parser(
         help="overwrite massaged TXT_FILENAME",
     )
 
+    parser.add_argument(
+        "-op",
+        "--open",
+        default=False,
+        action="store_true",
+        dest="open",
+        help="open the generated file using default program",
+    )
+
     parser.add_argument(
         "-q",
         "--quiet",
@@ -454,6 +491,14 @@ def build_parser(
         help="show debugging log and stacktrace",
     )
 
+    parser.add_argument(
+        "--env",
+        default=False,
+        action="store_true",
+        dest="env",
+        help="print environments information for bug reporting",
+    )
+
     parser.add_argument(
         "-h",
         "--help",
@@ -480,11 +525,17 @@ def main(args: Optional[Sequence[str]] = None):
         logger.debug(config)
 
         setup_logger(config)
+
+        start_time = time.time()
         run(config)
+        end_time = time.time()
+        elapsed_time = end_time - start_time
+        timedelta = datetime.timedelta(seconds=elapsed_time)
+        logger.info("Time taken: %s", timedelta)
 
     except Exception as error:
         logger.error(
             getattr(error, "message", str(error)),
-            exc_info=getattr(config, "debug", True),
+            exc_info=("-d" in args or "--debug" in args),
         )
         raise SystemExit(1) from None
